import 'package:flutter/material.dart';
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:get_settings/getsettings.dart';

void main() {
  runApp(const MyApp());
}

class MyApp extends StatefulWidget {
  const MyApp({Key? key}) : super(key: key);

  @override
  State<MyApp> createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  String _platformVersion = 'Unknown';
  bool _getsettings = false;
  final _getsettingsPlugin = GetSettings();

  @override
  void initState() {
    super.initState();
    initPlatformState();
    _getsettingsPlugin.onListenSettings((status1) {
      print(status1);
      _getsettings = status1['getsettingsOn'];
      setState(() {});
    }, (onError) {
      print('error:$onError');
    });
  }

  // Platform messages are asynchronous, so we initialize in an async method.
  Future<void> initPlatformState() async {
    String platformVersion;
    bool? getsettings = false;
    // Platform messages may fail, so we use a try/catch PlatformException.
    // We also handle the message potentially returning null.
    try {
      platformVersion = await _getsettingsPlugin.getPlatformVersion() ??
          'Unknown platform version';
      getsettings = await _getsettingsPlugin.isRotationOn();
    } on PlatformException {
      platformVersion = 'Failed to get platform version.';
    }

    // If the widget was removed from the tree while the asynchronous platform
    // message was in flight, we want to discard the reply rather than calling
    // setState to update our non-existent appearance.
    if (!mounted) return;

    setState(() {
      _platformVersion = platformVersion;
      _getsettings = getsettings!;
    });
    print('status1');
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: Center(
          child: Text(
              'Running on: $_platformVersion ,getsettings:$_getsettings\n'),
        ),
        floatingActionButton: IconButton(
          icon: const Icon(Icons.add_circle),
          onPressed: () async {
            _getsettings = (await _getsettingsPlugin.isRotationOn())!;
            print(_getsettings);
            setState(() {});
          },
        ),
      ),
    );
  }
}
